@@ -2,15 +2,16 @@
 #######################################################################
 """Interfaces for the Zope 3 based product package
 
-$Id: interfaces.py 49955 2008-02-06 20:26:35Z cray $
+$Id: interfaces.py 50946 2008-04-05 15:25:00Z cray $
 """
 __author__  = "Andrey Orlov, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49955 $"
+__version__ = "$Revision: 50946 $"
  
 from ng.content.annotation.annotationswitcher.interfaces import IAnnotationSwitcher
 from ng.content.annotation.dictannotation.interfaces import IDictAnnotationAble
 from ng.content.annotation.eventannotation.interfaces import IEventAnnotationAble
+from ng.content.annotation.productannotation.interfaces import IProductAnnotationAble
 
 class IAnnotationSwitcherDict(IAnnotationSwitcher,IDictAnnotationAble) :
     """Use as dictionary """
@@ -18,3 +19,6 @@ class IAnnotationSwitcherDict(IAnnotationSwitcher,IDictAnnotationAble) :
 class IAnnotationSwitcherEvent(IAnnotationSwitcher,IEventAnnotationAble) :
     """Use as Event """
 
+class IAnnotationSwitcherProduct(IAnnotationSwitcher,IProductAnnotationAble) :
+    """Use as Product """
+
