@@ -1,12 +1,13 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""EventAnnotation class for the Zope 3 based eventannotation package
+"""EventAnnotation class for the Zope 3 based
+ng.content.annotation.eventannotation package
 
-$Id: eventannotation.py 49955 2008-02-06 20:26:35Z cray $
+$Id: eventannotation.py 50946 2008-04-05 15:25:00Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49955 $"
+__version__ = "$Revision: 50946 $"
 
 from zope.interface import Interface
 from zope.interface import implements,implementedBy
