@@ -1,13 +1,15 @@
 ### -*- coding: utf-8 -*- #############################################
 #######################################################################
-"""Interfaces for the Zope 3 based product package
+"""Interfaces for the Zope 3 based ng.content.annotation.eventannotation
+package
 
-$Id: interfaces.py 49955 2008-02-06 20:26:35Z cray $
+$Id: interfaces.py 50946 2008-04-05 15:25:00Z cray $
 """
 __author__  = "Yegor Shershnev, 2007"
 __license__ = "GPL"
-__version__ = "$Revision: 49955 $"
- 
+__version__ = "$Revision: 50946 $"
+
+
 from zope.interface import Interface
 
 from zope.schema import Text, TextLine, Field, Bool, Datetime
